#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['manifestoo', 'manifestoo.commands', 'manifestoo.core_addons']

package_data = \
{'': ['*'],
 'manifestoo': ['.pytest_cache/*',
                '.pytest_cache/v/*',
                '.pytest_cache/v/cache/*'],
 'manifestoo.core_addons': ['.pytest_cache/*',
                            '.pytest_cache/v/*',
                            '.pytest_cache/v/cache/*']}

package_dir = \
{'': 'src'}

install_requires = \
['typer[all] ~=0.3.2']

extras_require = \
{":python_version<'3.7'": ['importlib_resources '],
 'doc': ['sphinx', 'furo', 'myst-parser', 'typer-cli', 'towncrier'],
 'test': ['pytest', 'coverage[toml]']}

entry_points = \
{'console_scripts': ['manifestoo = manifestoo.main:app',
                     'moo = manifestoo.main:app']}

setup(name='manifestoo',
      version='0.2',
      description='A tool to reason about Odoo addons manifests.',
      author='Stéphane Bidoul',
      author_email='stephane.bidoul@acsone.eu',
      url='https://github.com/sbidoul/manifestoo',
      packages=packages,
      package_data=package_data,
      package_dir=package_dir,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
